# kudu
[![Test Python Package](https://github.com/torfeld6/kudu/actions/workflows/python-test.yml/badge.svg)](https://github.com/torfeld6/kudu/actions/workflows/python-test.yml) [![codebeat badge](https://codebeat.co/badges/be7de81c-c082-41ad-ba1d-ca5ee2d0b07a)](https://codebeat.co/projects/github-com-torfeld6-kudu-master) [![Coverage Status](https://coveralls.io/repos/github/torfeld6/kudu/badge.svg?branch=master)](https://coveralls.io/github/torfeld6/kudu?branch=master)

## Release History
 - [0.9 (2019-10-29)](#09-2021-03-23)
 - [0.8 (2019-10-29)](#08-2021-01-19)
 - [0.7 (2019-10-29)](#07-2019-10-29)
 - [0.6 (2019-10-28)](#06-2019-10-28)
 - [0.5 (2019-06-17)](#05-2019-06-17)
 - [0.4 (2019-04-29)](#04-2019-04-29)
 - [0.2 (2019-04-29)](#02-2019-04-29)

### 0.9 (2021-03-23)
- adds push command category rules
- loosens up install requirements
- adds OS Independent test matrix
- moves interface folder based on filename
 
### 0.8 (2021-01-19)
- adds support for iOS UIs
 
### 0.7 (2019-10-29)
- adds path option to pull command
- downloads into current folder without config file  #4

### 0.6 (2019-10-28)
- adds path option to push command
 
### 0.5 (2019-06-17)
- requires requests >= 2.20.1

### 0.4 (2019-04-29)
- catches missing yaml.CLoader

### 0.2 (2019-04-29)
- adds push support for presentations
- fixes IOError being thrown for temporary IntelliJ files
